@@ -9,8 +9,8 @@ class MySQL(object):
 
     def __init__(self, username: str, password: str, host: str):
         self.host = host
-        self.username = quote(username, safe="!~*'();/?:@&=+$,#^_.&<>")
-        self.password = quote(password, safe="!~*'();/?:@&=+$,#^_.&<>")
+        self.username = quote(username, safe="!~*'();/?:&=+$,#^_.&<>")
+        self.password = quote(password, safe="!~*'();/?:&=+$,#^_.&<>")
 
     def __engine_mysql(self, schema: str):
         """Private function to create the connection engine"""
